# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - MoinDateSupport library (derived from EventAggregatorSupport)

    @copyright: 2008, 2009, 2010, 2011, 2012 by Paul Boddie <paul@boddie.org.uk>
    @license: GNU GPL (v2 or later), see COPYING.txt for details.
"""

from MoinSupport import *

__version__ = "0.1"

# User interface functions.

def getParameterDate(arg):

    "Interpret 'arg', recognising keywords and simple arithmetic operations."

    n = None

    if not arg:
        return None

    elif arg.startswith("current"):
        date = getCurrentDate()
        if len(arg) > 8:
            n = int(arg[7:])

    elif arg.startswith("yearstart"):
        date = Date((getCurrentYear(), 1, 1))
        if len(arg) > 10:
            n = int(arg[9:])

    elif arg.startswith("yearend"):
        date = Date((getCurrentYear(), 12, 31))
        if len(arg) > 8:
            n = int(arg[7:])

    else:
        date = getDate(arg)

    if n is not None:
        date = date.day_update(n)

    return date

def getParameterMonth(arg):

    "Interpret 'arg', recognising keywords and simple arithmetic operations."

    n = None

    if arg is None:
        return None

    elif arg.startswith("current"):
        date = getCurrentMonth()
        if len(arg) > 8:
            n = int(arg[7:])

    elif arg.startswith("yearstart"):
        date = Month((getCurrentYear(), 1))
        if len(arg) > 10:
            n = int(arg[9:])

    elif arg.startswith("yearend"):
        date = Month((getCurrentYear(), 12))
        if len(arg) > 8:
            n = int(arg[7:])

    else:
        date = getMonth(arg)

    if n is not None:
        date = date.month_update(n)

    return date

def getFormDate(request, calendar_name, argname):

    """
    Return the date from the 'request' for the calendar with the given
    'calendar_name' using the parameter having the given 'argname'.
    """

    arg = getQualifiedParameter(request, calendar_name, argname)
    return getParameterDate(arg)

def getFormMonth(request, calendar_name, argname):

    """
    Return the month from the 'request' for the calendar with the given
    'calendar_name' using the parameter having the given 'argname'.
    """

    arg = getQualifiedParameter(request, calendar_name, argname)
    return getParameterMonth(arg)

def getFormDateTriple(request, yeararg, montharg, dayarg):

    """
    Return the date from the 'request' for the calendar with the given
    'calendar_name' using the parameters having the given 'yeararg', 'montharg'
    and 'dayarg' names.
    """

    year = getParameter(request, yeararg)
    month = getParameter(request, montharg)
    day = getParameter(request, dayarg)
    if year and month and day:
        return Date((int(year), int(month), int(day)))
    else:
        return None

def getFormMonthPair(request, yeararg, montharg):

    """
    Return the month from the 'request' for the calendar with the given
    'calendar_name' using the parameters having the given 'yeararg' and
    'montharg' names.
    """

    year = getParameter(request, yeararg)
    month = getParameter(request, montharg)
    if year and month:
        return Month((int(year), int(month)))
    else:
        return None

def getFullDateLabel(request, date):

    """
    Return the full month plus year label using the given 'request' and
    'year_month'.
    """

    if not date:
        return ""

    _ = request.getText
    year, month, day = date.as_tuple()[:3]
    start_weekday, number_of_days = date.month_properties()
    weekday = (start_weekday + day - 1) % 7
    day_label = _(getDayLabel(weekday))
    month_label = _(getMonthLabel(month))
    return "%s %s %s %s" % (day_label, day, month_label, year)

def getFullMonthLabel(request, year_month):

    """
    Return the full month plus year label using the given 'request' and
    'year_month'.
    """

    if not year_month:
        return ""

    _ = request.getText
    year, month = year_month.as_tuple()[:2]
    month_label = _(getMonthLabel(month))
    return "%s %s" % (month_label, year)

# vim: tabstop=4 expandtab shiftwidth=4
